@@ -274,7 +274,7 @@ class RhythmAddOnClass:
         Return a complete mpd string of the current question that can
         be feed to utils.play_music.
         """
-        return r"\rhythmstaff{%s}" % self.get_music_notenames(True)
+        return r"\rhythmstaff{ \time 1000000/4 %s}" % self.get_music_notenames(True)
     def play_rhythm(self, rhythm):
         """
         rhythm is a string. Example: 'c4 c8 c8 c4'
@@ -394,6 +394,8 @@ class Gui(gtk.VBox, cfg.ConfigUtils, QstatusDefs):
              'repeat_arpeggio': _("Repeat _arpeggio"),
              'repeat_slowly': _("Repeat _slowly"),
              'repeat_melodic': _("Repeat _melodic"),
+             'repeat_first': _("Repeat first"),
+             'repeat_last': _("Repeat last"),
              'play_tonic': _("Play _tonic"),
              'play_music': _("P_lay music"),
              'play_answer': _("_Play answer"),
@@ -544,6 +546,8 @@ class Gui(gtk.VBox, cfg.ConfigUtils, QstatusDefs):
         """
         self.handle_config_box_visibility()
         self.handle_statistics_page_sensibility()
+        if getattr(self, 'g_flashbar', None):
+            self.g_flashbar.require_size(["|Xy"])
     def on_end_practise(self):
         pass
     def handle_config_box_visibility(self):
