@@ -152,8 +152,6 @@ class AccidentalsEngraver(Engraver):
 class KeySignatureEngraver(Engraver):
     def __init__(self, old_key, key, clef):
         Engraver.__init__(self)
-        self.m_old_key = old_key
-        self.m_key = key
         self.m_clef = clef
         self.m_old_accidentals = mpdutils.key_to_accidentals(old_key)
         self.m_accidentals = mpdutils.key_to_accidentals(key)
